==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lximage-qt/lximage-qt_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu_HU">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>Rólunk</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - az egyszerű és gyors képnéző

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <source>Open File</source>
        <translation>Fájl megnyitás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="243"/>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Image files (%1)</source>
        <translation>Képfájlok (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="264"/>
        <source>Save File</source>
        <translation>Fájl mentés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="530"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="535"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="539"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="576"/>
        <source>[*]Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Betöltés...) - Képnéző</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Betöltés sikertelen) - Képnéző</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (Loading...) - Képnéző</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Képnéző</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="819"/>
        <source>Thumbnails</source>
        <translation>Bélyegképek</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Képnéző</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>Ról&amp;am</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translation>&amp;Fájlnyitás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>&amp;Ment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>&amp;Másként ment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Nagyít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl++</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Kicsinyít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Vágólapra másol</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>Következő fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>Előző fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>Eredeti méret</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="299"/>
        <source>&amp;Fit</source>
        <translation>&amp;Kitölt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="309"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Jobbra forgat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="319"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>&amp;Balra forgat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="324"/>
        <source>P&amp;references</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="329"/>
        <source>&amp;Print</source>
        <translation>&amp;Nyomtat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="342"/>
        <source>First File</source>
        <translation>Első fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="355"/>
        <source>Last File</source>
        <translation>Utolsó fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>End</source>
        <translation>Vége</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="368"/>
        <source>&amp;New Window</source>
        <translation>&amp;Új ablak</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="376"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Vízszintesen átfordít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="386"/>
        <source>Capture Screenshot</source>
        <translation>Képernyókép készítés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Teljes kép</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Flip &amp;Vertically</source>
        <translation>&amp;Fejtetőre állít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Vágóla&amp;pról beilleszt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="425"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diavetítés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="435"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="446"/>
        <source>Show Thumbnails</source>
        <translation>Bélyegképek</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="451"/>
        <source>File Properties</source>
        <translation>Fájljellemzők</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>Ugrás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>&amp;Nézet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkeszt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>Eszközsáv</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Ikontéma:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normál háttérszín:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Teljeskép háttérszín:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Diaváltás (másodperc):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>Képernyőfénykép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>Terület</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>Teljes kép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>Aktuális ablak</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>Egérkurzor is</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>Ablakkeret és fejléc is</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lximage-qt/lximage-qt_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="91"/>
        <source>Take a screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="95"/>
        <source>[FILE1, FILE2,...]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="143"/>
        <source>About</source>
        <translation>Rólunk</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="144"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - az egyszerű és gyors képnéző

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="253"/>
        <source>Open File</source>
        <translation>Fájl megnyitás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="254"/>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Image files (%1)</source>
        <translation>Képfájlok (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="260"/>
        <source>Open directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Save File</source>
        <translation>Fájl mentés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="537"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="542"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="546"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="582"/>
        <source>[*]Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 (Loading...) - Image Viewer</source>
        <translation type="vanished">%1 (Betöltés...) - Képnéző</translation>
    </message>
    <message>
        <source>%1 (Failed to Load) - Image Viewer</source>
        <translation type="vanished">%1 (Betöltés sikertelen) - Képnéző</translation>
    </message>
    <message>
        <source>%1 (%2x%3) - Image Viewer</source>
        <translation type="vanished">%1 (Loading...) - Képnéző</translation>
    </message>
    <message>
        <source>Image Viewer</source>
        <translation type="vanished">Képnéző</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="842"/>
        <source>Thumbnails</source>
        <translation>Bélyegképek</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Képnéző</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="160"/>
        <source>&amp;About</source>
        <translation>Ról&amp;am</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="170"/>
        <source>&amp;Open File</source>
        <translation>&amp;Fájlnyitás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="173"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>&amp;Save</source>
        <translation>&amp;Ment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="186"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="196"/>
        <source>Save &amp;As</source>
        <translation>&amp;Másként ment</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="199"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezár</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="212"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="222"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Nagyít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="235"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Kicsinyít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="238"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="248"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Vágólapra másol</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="258"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Next File</source>
        <translation>Következő fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <location filename="../../mainwindow.ui" line="277"/>
        <source>Previous File</source>
        <translation>Előző fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="264"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="225"/>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="280"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="290"/>
        <source>Original Size</source>
        <translation>Eredeti méret</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="293"/>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="303"/>
        <source>&amp;Fit</source>
        <translation>&amp;Kitölt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="313"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Jobbra forgat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="323"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>&amp;Balra forgat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="328"/>
        <source>P&amp;references</source>
        <translation>&amp;Beállítások</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="333"/>
        <source>&amp;Print</source>
        <translation>&amp;Nyomtat</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="346"/>
        <source>First File</source>
        <translation>Első fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="349"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="359"/>
        <source>Last File</source>
        <translation>Utolsó fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="362"/>
        <source>End</source>
        <translation>Vége</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="372"/>
        <source>&amp;New Window</source>
        <translation>&amp;Új ablak</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="375"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="380"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Vízszintesen átfordít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="390"/>
        <source>Capture Screenshot</source>
        <translation>Képernyókép készítés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="398"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Teljes kép</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="401"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="406"/>
        <source>Flip &amp;Vertically</source>
        <translation>&amp;Fejtetőre állít</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="416"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>Vágóla&amp;pról beilleszt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="429"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diavetítés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="439"/>
        <source>&amp;Delete</source>
        <translation>&amp;Törlés</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="442"/>
        <source>Del</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="450"/>
        <source>Show Thumbnails</source>
        <translation>Bélyegképek</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="455"/>
        <source>File Properties</source>
        <translation>Fájljellemzők</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="463"/>
        <source>Open &amp;Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="466"/>
        <source>Ctrl+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Segítség</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Ugrás</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>&amp;Nézet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Szerkeszt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="121"/>
        <source>Toolbar</source>
        <translation>Eszközsáv</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Ikontéma:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Normál háttérszín:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Teljeskép háttérszín:</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Diaváltás (másodperc):</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Képernyőkép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Képernyőfénykép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Terület</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Teljes kép</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Aktuális ablak</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Egérkurzor is</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> másodperc</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Késleltetés:</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Ablakkeret és fejléc is</translation>
    </message>
</context>
</TS>
